# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`karaf`](#karaf): Install and configure Apache Karaf

#### Private Classes

* `karaf::install`
* `karaf::install::configuration`
* `karaf::install::configuration::karaf_management`
* `karaf::install::configuration::karaf_shell`
* `karaf::install::configuration::m2_settings`
* `karaf::install::configuration::mvn_url`
* `karaf::install::configuration::pid`
* `karaf::install::configuration::setenv`
* `karaf::install::configuration::users`
* `karaf::install::service`
* `karaf::install::service::service`
* `karaf::install::service::systemd`
* `karaf::install::user`
* `karaf::params`

## Classes

### <a name="karaf"></a>`karaf`

Install and configure Apache Karaf

#### Examples

##### 

```puppet
class { 'karaf': }
```

#### Parameters

The following parameters are available in the `karaf` class:

* [`ensure`](#-karaf--ensure)
* [`version`](#-karaf--version)
* [`rootdir`](#-karaf--rootdir)
* [`karaf_zip_url`](#-karaf--karaf_zip_url)
* [`manage_user`](#-karaf--manage_user)
* [`service_user_name`](#-karaf--service_user_name)
* [`service_user_id`](#-karaf--service_user_id)
* [`service_group_name`](#-karaf--service_group_name)
* [`service_group_id`](#-karaf--service_group_id)
* [`service_name`](#-karaf--service_name)
* [`service_provider`](#-karaf--service_provider)
* [`java_home`](#-karaf--java_home)
* [`default_env_vars`](#-karaf--default_env_vars)
* [`karaf_users_definition`](#-karaf--karaf_users_definition)
* [`karaf_ssh_host`](#-karaf--karaf_ssh_host)
* [`karaf_ssh_port`](#-karaf--karaf_ssh_port)
* [`mvn_repositories`](#-karaf--mvn_repositories)
* [`m2_settings`](#-karaf--m2_settings)
* [`karaf_rmi_registry_host`](#-karaf--karaf_rmi_registry_host)
* [`karaf_rmi_registry_port`](#-karaf--karaf_rmi_registry_port)
* [`karaf_rmi_server_host`](#-karaf--karaf_rmi_server_host)
* [`karaf_rmi_server_port`](#-karaf--karaf_rmi_server_port)
* [`pidfile`](#-karaf--pidfile)

##### <a name="-karaf--ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Specifies whether Apache Karaf should be installed.

Default value: `'present'`

##### <a name="-karaf--version"></a>`version`

Data type: `String`

Version of Apache Karaf to install.

Default value: `$karaf::params::version`

##### <a name="-karaf--rootdir"></a>`rootdir`

Data type: `Stdlib::Absolutepath`

Root directory in which to install Apache Karaf.

Default value: `$karaf::params::rootdir`

##### <a name="-karaf--karaf_zip_url"></a>`karaf_zip_url`

Data type: `String`

URL where the Karaf ZIP can be downloaded. '${version}' will be replaced withe the configured version.

Default value: `$karaf::params::karaf_zip_url`

##### <a name="-karaf--manage_user"></a>`manage_user`

Data type: `Boolean`

Should this module create Unix user and group.

Default value: `$karaf::params::manage_user`

##### <a name="-karaf--service_user_name"></a>`service_user_name`

Data type: `String`

As which Unix user to run Karaf.

Default value: `$karaf::params::service_user_name`

##### <a name="-karaf--service_user_id"></a>`service_user_id`

Data type: `Integer`

UID to use to create the Unix user.

Default value: `$karaf::params::service_user_id`

##### <a name="-karaf--service_group_name"></a>`service_group_name`

Data type: `String`

As which Unix group to run Karaf.

Default value: `$karaf::params::service_group_name`

##### <a name="-karaf--service_group_id"></a>`service_group_id`

Data type: `Integer`

GID to use to create the Unix group.

Default value: `$karaf::params::service_group_id`

##### <a name="-karaf--service_name"></a>`service_name`

Data type: `String`

Name of the Unix service to install.

Default value: `$karaf::params::service_name`

##### <a name="-karaf--service_provider"></a>`service_provider`

Data type: `Enum['systemd', 'init']`

Is the system using init.d or systemd to run system services.

Default value: `$karaf::params::service_provider`

##### <a name="-karaf--java_home"></a>`java_home`

Data type: `Stdlib::Absolutepath`

Home of Java installation.

Default value: `$karaf::params::java_home`

##### <a name="-karaf--default_env_vars"></a>`default_env_vars`

Data type: `Hash[String, String]`

Default environment variables to set.

Default value: `$karaf::params::default_env_vars`

##### <a name="-karaf--karaf_users_definition"></a>`karaf_users_definition`

Data type: `Hash[String, String]`

Definition of Karaf users and groups.

Default value: `$karaf::params::karaf_users_definition`

##### <a name="-karaf--karaf_ssh_host"></a>`karaf_ssh_host`

Data type: `String`

Host definition of where SSH should listen.

Default value: `$karaf::params::karaf_ssh_host`

##### <a name="-karaf--karaf_ssh_port"></a>`karaf_ssh_port`

Data type: `Integer`

Port definition of where SSH should listen.

Default value: `$karaf::params::karaf_ssh_port`

##### <a name="-karaf--mvn_repositories"></a>`mvn_repositories`

Data type: `Array[String]`

Maven repositories.

Default value: `$karaf::params::mvn_repositories`

##### <a name="-karaf--m2_settings"></a>`m2_settings`

Data type: `Struct[{ Optional[servers] => Array, Optional[mirrors] => Array }]`

Maven settings.

Default value: `$karaf::params::m2_settings`

##### <a name="-karaf--karaf_rmi_registry_host"></a>`karaf_rmi_registry_host`

Data type: `String`

Host definition of where RMI registry should listen.

Default value: `$karaf::params::karaf_rmi_registry_host`

##### <a name="-karaf--karaf_rmi_registry_port"></a>`karaf_rmi_registry_port`

Data type: `Integer`

Port definition of where RMI registry should listen.

Default value: `$karaf::params::karaf_rmi_registry_port`

##### <a name="-karaf--karaf_rmi_server_host"></a>`karaf_rmi_server_host`

Data type: `String`

Host definition of where RMI server should listen.

Default value: `$karaf::params::karaf_rmi_server_host`

##### <a name="-karaf--karaf_rmi_server_port"></a>`karaf_rmi_server_port`

Data type: `Integer`

Port definition of where RMI server should listen.

Default value: `$karaf::params::karaf_rmi_server_port`

##### <a name="-karaf--pidfile"></a>`pidfile`

Data type: `Stdlib::Absolutepath`

Where to store PID file.

Default value: `$karaf::params::pidfile`

